'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_I3D_gamma'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_I3D_gamma',error_checker=_errors._error_checker)
WGL_GAMMA_EXCLUDE_DESKTOP_I3D=_C('WGL_GAMMA_EXCLUDE_DESKTOP_I3D',0x204F)
WGL_GAMMA_TABLE_SIZE_I3D=_C('WGL_GAMMA_TABLE_SIZE_I3D',0x204E)
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.c_int,ctypes.POINTER(_cs.USHORT),ctypes.POINTER(_cs.USHORT),ctypes.POINTER(_cs.USHORT))
def wglGetGammaTableI3D(hDC,iEntries,puRed,puGreen,puBlue):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.c_int,ctypes.POINTER(_cs.c_int))
def wglGetGammaTableParametersI3D(hDC,iAttribute,piValue):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.c_int,ctypes.POINTER(_cs.USHORT),ctypes.POINTER(_cs.USHORT),ctypes.POINTER(_cs.USHORT))
def wglSetGammaTableI3D(hDC,iEntries,puRed,puGreen,puBlue):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.c_int,ctypes.POINTER(_cs.c_int))
def wglSetGammaTableParametersI3D(hDC,iAttribute,piValue):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_matrix_palette'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_matrix_palette',error_checker=_errors._error_checker)
GL_CURRENT_MATRIX_INDEX_ARB=_C('GL_CURRENT_MATRIX_INDEX_ARB',0x8845)
GL_CURRENT_PALETTE_MATRIX_ARB=_C('GL_CURRENT_PALETTE_MATRIX_ARB',0x8843)
GL_MATRIX_INDEX_ARRAY_ARB=_C('GL_MATRIX_INDEX_ARRAY_ARB',0x8844)
GL_MATRIX_INDEX_ARRAY_POINTER_ARB=_C('GL_MATRIX_INDEX_ARRAY_POINTER_ARB',0x8849)
GL_MATRIX_INDEX_ARRAY_SIZE_ARB=_C('GL_MATRIX_INDEX_ARRAY_SIZE_ARB',0x8846)
GL_MATRIX_INDEX_ARRAY_STRIDE_ARB=_C('GL_MATRIX_INDEX_ARRAY_STRIDE_ARB',0x8848)
GL_MATRIX_INDEX_ARRAY_TYPE_ARB=_C('GL_MATRIX_INDEX_ARRAY_TYPE_ARB',0x8847)
GL_MATRIX_PALETTE_ARB=_C('GL_MATRIX_PALETTE_ARB',0x8840)
GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB=_C('GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB',0x8841)
GL_MAX_PALETTE_MATRICES_ARB=_C('GL_MAX_PALETTE_MATRICES_ARB',0x8842)
@_f
@_p.types(None,_cs.GLint)
def glCurrentPaletteMatrixARB(index):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glMatrixIndexPointerARB(size,type,stride,pointer):pass
@_f
@_p.types(None,_cs.GLint,arrays.GLubyteArray)
def glMatrixIndexubvARB(size,indices):pass
@_f
@_p.types(None,_cs.GLint,arrays.GLuintArray)
def glMatrixIndexuivARB(size,indices):pass
@_f
@_p.types(None,_cs.GLint,arrays.GLushortArray)
def glMatrixIndexusvARB(size,indices):pass



"""GLE exceptional functions (specialised signatures"""
from OpenGL.raw import GLE as raw
from OpenGL.raw.GLE import annotations as _simple

from OpenGL import wrapper, arrays

class _lengthOfArgname( object ):
    """Calculates the length of a given argname over a divisor value"""
    def __init__( self, arrayName, divisor, arrayType = arrays.GLdoubleArray ):
        self.arrayName = arrayName
        self.divisor = divisor
        self.arrayType = arrayType
    def finalise( self, wrapper ):
        self.arrayIndex = wrapper.pyArgIndex( self.arrayName )
    def __call__( self, pyArgs, index, wrappedOperation ):
        """Get the length of pyArgs[2], a glDoubleArray"""
        return self.arrayType.arraySize( pyArgs[self.arrayIndex] )//self.divisor
def _baseWrap( base, lengthName='ncp', contourName='contour', divisor=2 ):
    """Do the basic wrapping operation for a GLE function"""
    return wrapper.wrapper( base ).setPyConverter(
        lengthName,
    ).setCConverter(
        lengthName, _lengthOfArgname( contourName, divisor, arrays.GLdoubleArray ),
    )

gleLathe = _baseWrap( _simple.gleLathe )
glePolyCone = _baseWrap( _simple.glePolyCone, 'npoints', 'point_array', 3)
glePolyCylinder = _baseWrap( _simple.glePolyCylinder, 'npoints', 'point_array', 3)
gleScrew = _baseWrap( _simple.gleScrew )
gleSpiral = _baseWrap( _simple.gleSpiral )

gleExtrusion = _baseWrap( 
    _baseWrap( _simple.gleExtrusion ),
    'npoints', 'point_array', 3
)
gleSuperExtrusion = _baseWrap( 
    _baseWrap( _simple.gleSuperExtrusion ),
    'npoints', 'point_array', 3
)
gleTwistExtrusion = _baseWrap( 
    _baseWrap( _simple.gleTwistExtrusion ),
    'npoints', 'point_array', 3
)


'''OpenGL extension EXT.bindable_uniform

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.bindable_uniform to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces the concept of bindable uniforms to the OpenGL
	Shading Language.  A uniform variable can be declared bindable, which
	means that the storage for the uniform is not allocated by the
	compiler/linker anymore, but is backed by a buffer object.  This buffer
	object is bound to the bindable uniform through the new command
	UniformBufferEXT().  Binding needs to happen after linking a program
	object.
	
	Binding different buffer objects to a bindable uniform allows an
	application to easily use different "uniform data sets", without having to
	re-specify the data every time.
	
	A buffer object can be bound to bindable uniforms in different program
	objects. If those bindable uniforms are all of the same type, accessing a
	bindable uniform in program object A will result in the same data if the
	same access is made in program object B.  This provides a mechanism for
	'environment uniforms', uniform values that can be shared among multiple
	program objects.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/bindable_uniform.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.bindable_uniform import *
from OpenGL.raw.GL.EXT.bindable_uniform import _EXTENSION_NAME

def glInitBindableUniformEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension APPLE.fence

This module customises the behaviour of the 
OpenGL.raw.GL.APPLE.fence to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension is provided a finer granularity of synchronizing GL command
	completion than offered by standard OpenGL, which currently offers only two
	mechanisms for synchronization: Flush and Finish. Since Flush merely assures
	the user that the commands complete in a finite (though undetermined) amount
	of time, it is, thus, of only modest utility.  Finish, on the other hand,
	stalls CPU execution until all pending GL commands have completed forcing
	completely synchronous operation, which most often not the desired result.
	This extension offers a middle ground - the ability to "finish" a subset of
	the command stream, and the ability to determine whether a given command has
	completed or not.
	
	This extension introduces the concept of a "fence" to the OpenGL command
	stream with SetFenceAPPLE.  Once the fence is inserted into the command
	stream, it can be tested for its completion with TestFenceAPPLE. Moreover,
	the application may also request a partial Finish up to a particular "fence"
	using the FinishFenceAPPLE command -- that is, all commands prior to the
	fence will be forced to complete until control is returned to the calling
	process.  These new mechanisms allow for synchronization between the host
	CPU and the GPU, which may be accessing the same resources (typically
	memory).
	
	Fences are created and deleted, as are other objects in OpenGL, specifically
	with GenFencesAPPLE and DeleteFencesAPPLE.  The former returns a list of
	unused fence names and the later deletes the provided list of fence names.
	
	In addition to being able to test or finish a fence this extension allows
	testing for other types of completion, including texture objects, vertex
	array objects, and draw pixels. This allows the client to use
	TestObjectAPPLE or FinishObjectAPPLE with FENCE_APPLE, TEXTURE,
	VERTEX_ARRAY, or DRAW_PIXELS_APPLE with the same type of results as
	TestFenceAPPLE and FinishFenceAPPLE.  Specifically, using the FENCE_APPLE
	type is equivalent to calling TestFenceAPPLE or FinishFenceAPPLE with the
	particular fence name.  Using TEXTURE as the object type tests or waits for
	completion of a specific texture, meaning when there are no pending
	rendering commands which use that texture object. Using the VERTEX_ARRAY
	type will test or wait for drawing commands using that particular vertex
	array object name.  Finally, DRAW_PIXELS_APPLE will wait or test for
	completion of all pending DrawPixels commands.  These tests and finishes
	operate with the same limitations and results as test and finish fence.
	
	One use of this extension is in conjunction with APPLE_vertex_array_range to
	determine when graphics hardware has completed accessing vertex data from a
	vertex array range.  Once a fence has been tested TRUE or finished, all
	vertex indices issued before the fence must have completed being accessed.
	This ensures that the vertex data memory corresponding to the issued vertex
	indices can be safely modified (assuming no other outstanding vertex indices
	are issued subsequent to the fence).

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/fence.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.APPLE.fence import *
from OpenGL.raw.GL.APPLE.fence import _EXTENSION_NAME

def glInitFenceAPPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glGenFencesAPPLE=wrapper.wrapper(glGenFencesAPPLE).setOutput(
    'fences',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
# INPUT glDeleteFencesAPPLE.fences size not checked against n
glDeleteFencesAPPLE=wrapper.wrapper(glDeleteFencesAPPLE).setInputArraySize(
    'fences', None
)
### END AUTOGENERATED SECTION


"""Array-size annotations for OpenGL.raw.GLUT

Automatically generated by the generateraw script, do not edit!
"""
from OpenGL.raw import GLUT as raw

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL.raw.GL import _types as GL_types
GLvoid = GL_types.GLvoid

STRING = c_char_p



__all__ = [
    
]



'''OpenGL extension ARB.clear_buffer_object

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.clear_buffer_object to provide a more 
Python-friendly API

Overview (from the spec)
	
	Buffer objects are fundamental to the operation of OpenGL. Buffers are used
	as a source of data for vertices and indices, read through buffer textures
	in shaders, used to transfer texture and image data into and out of
	textures and framebuffers, and may be written to by operations such as
	transform feedback. OpenGL contains mechanisms to copy sections of buffers
	from one to another, but it has no mechanism to initialize the content
	of a buffer to a known value. In effect, it has memcpy, but not memset.
	
	This extension adds such a mechanism and has several use cases. Examples
	include clearing a pixel unpack buffer before transferring data to
	a texture or resetting buffer data to a known value before sparse updates
	through shader image stores or transform feedback.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/clear_buffer_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.clear_buffer_object import *
from OpenGL.raw.GL.ARB.clear_buffer_object import _EXTENSION_NAME

def glInitClearBufferObjectARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glClearBufferData.data size not checked against 'format,type'
glClearBufferData=wrapper.wrapper(glClearBufferData).setInputArraySize(
    'data', None
)
# INPUT glClearBufferSubData.data size not checked against 'format,type'
glClearBufferSubData=wrapper.wrapper(glClearBufferSubData).setInputArraySize(
    'data', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_disjoint_timer_query'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_disjoint_timer_query',error_checker=_errors._error_checker)
GL_CURRENT_QUERY_EXT=_C('GL_CURRENT_QUERY_EXT',0x8865)
GL_GPU_DISJOINT_EXT=_C('GL_GPU_DISJOINT_EXT',0x8FBB)
GL_QUERY_COUNTER_BITS_EXT=_C('GL_QUERY_COUNTER_BITS_EXT',0x8864)
GL_QUERY_RESULT_AVAILABLE_EXT=_C('GL_QUERY_RESULT_AVAILABLE_EXT',0x8867)
GL_QUERY_RESULT_EXT=_C('GL_QUERY_RESULT_EXT',0x8866)
GL_TIMESTAMP_EXT=_C('GL_TIMESTAMP_EXT',0x8E28)
GL_TIME_ELAPSED_EXT=_C('GL_TIME_ELAPSED_EXT',0x88BF)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBeginQueryEXT(target,id):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteQueriesEXT(n,ids):pass
@_f
@_p.types(None,_cs.GLenum)
def glEndQueryEXT(target):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenQueriesEXT(n,ids):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLint64Array)
def glGetQueryObjecti64vEXT(id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetQueryObjectivEXT(id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuint64Array)
def glGetQueryObjectui64vEXT(id,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuintArray)
def glGetQueryObjectuivEXT(id,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetQueryivEXT(target,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsQueryEXT(id):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum)
def glQueryCounterEXT(id,target):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_cull_vertex'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_cull_vertex',error_checker=_errors._error_checker)
GL_CULL_VERTEX_EXT=_C('GL_CULL_VERTEX_EXT',0x81AA)
GL_CULL_VERTEX_EYE_POSITION_EXT=_C('GL_CULL_VERTEX_EYE_POSITION_EXT',0x81AB)
GL_CULL_VERTEX_OBJECT_POSITION_EXT=_C('GL_CULL_VERTEX_OBJECT_POSITION_EXT',0x81AC)
@_f
@_p.types(None,_cs.GLenum,arrays.GLdoubleArray)
def glCullParameterdvEXT(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glCullParameterfvEXT(pname,params):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_OML_sync_control'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_OML_sync_control',error_checker=_errors._error_checker)

@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),_cs.GLXDrawable,ctypes.POINTER(_cs.int32_t),ctypes.POINTER(_cs.int32_t))
def glXGetMscRateOML(dpy,drawable,numerator,denominator):pass
@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),_cs.GLXDrawable,ctypes.POINTER(_cs.int64_t),ctypes.POINTER(_cs.int64_t),ctypes.POINTER(_cs.int64_t))
def glXGetSyncValuesOML(dpy,drawable,ust,msc,sbc):pass
@_f
@_p.types(_cs.int64_t,ctypes.POINTER(_cs.Display),_cs.GLXDrawable,_cs.int64_t,_cs.int64_t,_cs.int64_t)
def glXSwapBuffersMscOML(dpy,drawable,target_msc,divisor,remainder):pass
@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),_cs.GLXDrawable,_cs.int64_t,_cs.int64_t,_cs.int64_t,ctypes.POINTER(_cs.int64_t),ctypes.POINTER(_cs.int64_t),ctypes.POINTER(_cs.int64_t))
def glXWaitForMscOML(dpy,drawable,target_msc,divisor,remainder,ust,msc,sbc):pass
@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),_cs.GLXDrawable,_cs.int64_t,ctypes.POINTER(_cs.int64_t),ctypes.POINTER(_cs.int64_t),ctypes.POINTER(_cs.int64_t))
def glXWaitForSbcOML(dpy,drawable,target_sbc,ust,msc,sbc):pass



'''OpenGL extension SGIX.instruments

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.instruments to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows the gathering and return of performance
	measurements from within the graphics pipeline by adding
	instrumentation.
	
	There are two reasons to do this.  The first is as a part of some
	type of fixed-frame-rate load management scheme.  If we know that
	the pipeline is stalled or struggling to process the amount of
	data we have given it so far, we can reduce the level of detail of
	the remaining objects in the current frame or the next frame, or
	adjust the framebuffer resolution for the next frame if we have a
	video-zoom capability available.  We can call this type of
	instrumentation Load Monitoring.
	
	The second is for performance tuning and debugging of an
	application. It might tell us how many triangles were culled or
	clipped before being rasterized.  We can call this simply Tuning.
	
	Load Monitoring requires that the instrumentation and the access
	of the measurements be efficient, otherwise the instrumentation
	itself will reduce performance more than any load-management
	scheme could hope to offset.  Tuning does not have the same
	requirements.
	
	The proposed extension adds a call to setup a measurements return
	buffer, similar to FeedbackBuffer but with an asynchrounous
	behavior to prevent filling the pipeline with NOP's while waiting
	for the data to be returned.
	
	Note that although the extension has been specified without any
	particular instruments, defining either a device dependent or
	device independent instrument should be as simple as introducing
	an extension consisting primarily of a new enumerant to identify
	the instrument.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/instruments.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.instruments import *
from OpenGL.raw.GL.SGIX.instruments import _EXTENSION_NAME

def glInitInstrumentsSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glInstrumentsBufferSGIX=wrapper.wrapper(glInstrumentsBufferSGIX).setOutput(
    'buffer',size=lambda x:(x,),pnameArg='size',orPassIn=True
)
glPollInstrumentsSGIX=wrapper.wrapper(glPollInstrumentsSGIX).setOutput(
    'marker_p',size=(1,),orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension EXT.blend_minmax

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.blend_minmax to provide a more 
Python-friendly API

Overview (from the spec)
	
	Blending capability is extended by respecifying the entire blend
	equation.  While this document defines only two new equations, the
	BlendEquationEXT procedure that it defines will be used by subsequent
	extensions to define additional blending equations.
	
	The two new equations defined by this extension produce the minimum
	(or maximum) color components of the source and destination colors.
	Taking the maximum is useful for applications such as maximum projection
	in medical imaging.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/blend_minmax.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.blend_minmax import *
from OpenGL.raw.GLES2.EXT.blend_minmax import _EXTENSION_NAME

def glInitBlendMinmaxEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.blend_logic_op

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.blend_logic_op to provide a more 
Python-friendly API

Overview (from the spec)
	
	A single additional blending equation is specified using the interface
	defined by EXT_blend_minmax.  This equation is a simple logical
	combination of the source and destination colors, where the specific
	logical operation is as specified by LogicOp.  While only the XOR
	operation may find wide application, the generality of full logical
	operations is allowed.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/blend_logic_op.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.blend_logic_op import *
from OpenGL.raw.GL.EXT.blend_logic_op import _EXTENSION_NAME

def glInitBlendLogicOpEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ATI_pn_triangles'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ATI_pn_triangles',error_checker=_errors._error_checker)
GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI=_C('GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI',0x87F1)
GL_PN_TRIANGLES_ATI=_C('GL_PN_TRIANGLES_ATI',0x87F0)
GL_PN_TRIANGLES_NORMAL_MODE_ATI=_C('GL_PN_TRIANGLES_NORMAL_MODE_ATI',0x87F3)
GL_PN_TRIANGLES_NORMAL_MODE_LINEAR_ATI=_C('GL_PN_TRIANGLES_NORMAL_MODE_LINEAR_ATI',0x87F7)
GL_PN_TRIANGLES_NORMAL_MODE_QUADRATIC_ATI=_C('GL_PN_TRIANGLES_NORMAL_MODE_QUADRATIC_ATI',0x87F8)
GL_PN_TRIANGLES_POINT_MODE_ATI=_C('GL_PN_TRIANGLES_POINT_MODE_ATI',0x87F2)
GL_PN_TRIANGLES_POINT_MODE_CUBIC_ATI=_C('GL_PN_TRIANGLES_POINT_MODE_CUBIC_ATI',0x87F6)
GL_PN_TRIANGLES_POINT_MODE_LINEAR_ATI=_C('GL_PN_TRIANGLES_POINT_MODE_LINEAR_ATI',0x87F5)
GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI=_C('GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI',0x87F4)
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glPNTrianglesfATI(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glPNTrianglesiATI(pname,param):pass



'''OpenGL extension AMD.shader_trinary_minmax

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.shader_trinary_minmax to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces three new trinary built-in functions to the
	OpenGL Shading Languages. These functions allow the minimum, maximum
	or median of three inputs to be found with a single function call. These
	operations may be useful for sorting and filtering operations, for example.
	By explicitly performing a trinary operation with a single built-in
	function, shader compilers and optimizers may be able to generate better
	instruction sequences for perform sorting and other multi-input functions.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/shader_trinary_minmax.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.shader_trinary_minmax import *
from OpenGL.raw.GL.AMD.shader_trinary_minmax import _EXTENSION_NAME

def glInitShaderTrinaryMinmaxAMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_VERSION_GL_1_2'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_VERSION_GL_1_2',error_checker=_errors._error_checker)
GL_ALIASED_LINE_WIDTH_RANGE=_C('GL_ALIASED_LINE_WIDTH_RANGE',0x846E)
GL_ALIASED_POINT_SIZE_RANGE=_C('GL_ALIASED_POINT_SIZE_RANGE',0x846D)
GL_BGR=_C('GL_BGR',0x80E0)
GL_BGRA=_C('GL_BGRA',0x80E1)
GL_CLAMP_TO_EDGE=_C('GL_CLAMP_TO_EDGE',0x812F)
GL_LIGHT_MODEL_COLOR_CONTROL=_C('GL_LIGHT_MODEL_COLOR_CONTROL',0x81F8)
GL_MAX_3D_TEXTURE_SIZE=_C('GL_MAX_3D_TEXTURE_SIZE',0x8073)
GL_MAX_ELEMENTS_INDICES=_C('GL_MAX_ELEMENTS_INDICES',0x80E9)
GL_MAX_ELEMENTS_VERTICES=_C('GL_MAX_ELEMENTS_VERTICES',0x80E8)
GL_PACK_IMAGE_HEIGHT=_C('GL_PACK_IMAGE_HEIGHT',0x806C)
GL_PACK_SKIP_IMAGES=_C('GL_PACK_SKIP_IMAGES',0x806B)
GL_PROXY_TEXTURE_3D=_C('GL_PROXY_TEXTURE_3D',0x8070)
GL_RESCALE_NORMAL=_C('GL_RESCALE_NORMAL',0x803A)
GL_SEPARATE_SPECULAR_COLOR=_C('GL_SEPARATE_SPECULAR_COLOR',0x81FA)
GL_SINGLE_COLOR=_C('GL_SINGLE_COLOR',0x81F9)
GL_SMOOTH_LINE_WIDTH_GRANULARITY=_C('GL_SMOOTH_LINE_WIDTH_GRANULARITY',0x0B23)
GL_SMOOTH_LINE_WIDTH_RANGE=_C('GL_SMOOTH_LINE_WIDTH_RANGE',0x0B22)
GL_SMOOTH_POINT_SIZE_GRANULARITY=_C('GL_SMOOTH_POINT_SIZE_GRANULARITY',0x0B13)
GL_SMOOTH_POINT_SIZE_RANGE=_C('GL_SMOOTH_POINT_SIZE_RANGE',0x0B12)
GL_TEXTURE_3D=_C('GL_TEXTURE_3D',0x806F)
GL_TEXTURE_BASE_LEVEL=_C('GL_TEXTURE_BASE_LEVEL',0x813C)
GL_TEXTURE_BINDING_3D=_C('GL_TEXTURE_BINDING_3D',0x806A)
GL_TEXTURE_DEPTH=_C('GL_TEXTURE_DEPTH',0x8071)
GL_TEXTURE_MAX_LEVEL=_C('GL_TEXTURE_MAX_LEVEL',0x813D)
GL_TEXTURE_MAX_LOD=_C('GL_TEXTURE_MAX_LOD',0x813B)
GL_TEXTURE_MIN_LOD=_C('GL_TEXTURE_MIN_LOD',0x813A)
GL_TEXTURE_WRAP_R=_C('GL_TEXTURE_WRAP_R',0x8072)
GL_UNPACK_IMAGE_HEIGHT=_C('GL_UNPACK_IMAGE_HEIGHT',0x806E)
GL_UNPACK_SKIP_IMAGES=_C('GL_UNPACK_SKIP_IMAGES',0x806D)
GL_UNSIGNED_BYTE_2_3_3_REV=_C('GL_UNSIGNED_BYTE_2_3_3_REV',0x8362)
GL_UNSIGNED_BYTE_3_3_2=_C('GL_UNSIGNED_BYTE_3_3_2',0x8032)
GL_UNSIGNED_INT_10_10_10_2=_C('GL_UNSIGNED_INT_10_10_10_2',0x8036)
GL_UNSIGNED_INT_2_10_10_10_REV=_C('GL_UNSIGNED_INT_2_10_10_10_REV',0x8368)
GL_UNSIGNED_INT_8_8_8_8=_C('GL_UNSIGNED_INT_8_8_8_8',0x8035)
GL_UNSIGNED_INT_8_8_8_8_REV=_C('GL_UNSIGNED_INT_8_8_8_8_REV',0x8367)
GL_UNSIGNED_SHORT_1_5_5_5_REV=_C('GL_UNSIGNED_SHORT_1_5_5_5_REV',0x8366)
GL_UNSIGNED_SHORT_4_4_4_4=_C('GL_UNSIGNED_SHORT_4_4_4_4',0x8033)
GL_UNSIGNED_SHORT_4_4_4_4_REV=_C('GL_UNSIGNED_SHORT_4_4_4_4_REV',0x8365)
GL_UNSIGNED_SHORT_5_5_5_1=_C('GL_UNSIGNED_SHORT_5_5_5_1',0x8034)
GL_UNSIGNED_SHORT_5_6_5=_C('GL_UNSIGNED_SHORT_5_6_5',0x8363)
GL_UNSIGNED_SHORT_5_6_5_REV=_C('GL_UNSIGNED_SHORT_5_6_5_REV',0x8364)
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glCopyTexSubImage3D(target,level,xoffset,yoffset,zoffset,x,y,width,height):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLsizei,_cs.GLenum,ctypes.c_void_p)
def glDrawRangeElements(mode,start,end,count,type,indices):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLint,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexImage3D(target,level,internalformat,width,height,depth,border,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexSubImage3D(target,level,xoffset,yoffset,zoffset,width,height,depth,format,type,pixels):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_EXT_display_color_table'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_EXT_display_color_table',error_checker=_errors._error_checker)

@_f
@_p.types(_cs.GLboolean,_cs.GLushort)
def wglBindDisplayColorTableEXT(id):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLushort)
def wglCreateDisplayColorTableEXT(id):pass
@_f
@_p.types(_cs.VOID,_cs.GLushort)
def wglDestroyDisplayColorTableEXT(id):pass
@_f
@_p.types(_cs.GLboolean,arrays.GLushortArray,_cs.GLuint)
def wglLoadDisplayColorTableEXT(table,length):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_robustness'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_robustness',error_checker=_errors._error_checker)
GL_CONTEXT_FLAG_ROBUST_ACCESS_BIT_ARB=_C('GL_CONTEXT_FLAG_ROBUST_ACCESS_BIT_ARB',0x00000004)
GL_GUILTY_CONTEXT_RESET_ARB=_C('GL_GUILTY_CONTEXT_RESET_ARB',0x8253)
GL_INNOCENT_CONTEXT_RESET_ARB=_C('GL_INNOCENT_CONTEXT_RESET_ARB',0x8254)
GL_LOSE_CONTEXT_ON_RESET_ARB=_C('GL_LOSE_CONTEXT_ON_RESET_ARB',0x8252)
GL_NO_ERROR=_C('GL_NO_ERROR',0)
GL_NO_RESET_NOTIFICATION_ARB=_C('GL_NO_RESET_NOTIFICATION_ARB',0x8261)
GL_RESET_NOTIFICATION_STRATEGY_ARB=_C('GL_RESET_NOTIFICATION_STRATEGY_ARB',0x8256)
GL_UNKNOWN_CONTEXT_RESET_ARB=_C('GL_UNKNOWN_CONTEXT_RESET_ARB',0x8255)
@_f
@_p.types(_cs.GLenum,)
def glGetGraphicsResetStatusARB():pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glGetnColorTableARB(target,format,type,bufSize,table):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLsizei,ctypes.c_void_p)
def glGetnCompressedTexImageARB(target,lod,bufSize,img):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glGetnConvolutionFilterARB(target,format,type,bufSize,image):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLboolean,_cs.GLenum,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glGetnHistogramARB(target,reset,format,type,bufSize,values):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,arrays.GLdoubleArray)
def glGetnMapdvARB(target,query,bufSize,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,arrays.GLfloatArray)
def glGetnMapfvARB(target,query,bufSize,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,arrays.GLintArray)
def glGetnMapivARB(target,query,bufSize,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLboolean,_cs.GLenum,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glGetnMinmaxARB(target,reset,format,type,bufSize,values):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLfloatArray)
def glGetnPixelMapfvARB(map,bufSize,values):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLuintArray)
def glGetnPixelMapuivARB(map,bufSize,values):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,arrays.GLushortArray)
def glGetnPixelMapusvARB(map,bufSize,values):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLubyteArray)
def glGetnPolygonStippleARB(bufSize,pattern):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p,_cs.GLsizei,ctypes.c_void_p,ctypes.c_void_p)
def glGetnSeparableFilterARB(target,format,type,rowBufSize,row,columnBufSize,column,span):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glGetnTexImageARB(target,level,format,type,bufSize,img):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLdoubleArray)
def glGetnUniformdvARB(program,location,bufSize,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLfloatArray)
def glGetnUniformfvARB(program,location,bufSize,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLintArray)
def glGetnUniformivARB(program,location,bufSize,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLsizei,arrays.GLuintArray)
def glGetnUniformuivARB(program,location,bufSize,params):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glReadnPixelsARB(x,y,width,height,format,type,bufSize,data):pass



'''OpenGL extension EXT.blend_subtract

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.blend_subtract to provide a more 
Python-friendly API

Overview (from the spec)
	
	Two additional blending equations are specified using the interface
	defined by EXT_blend_minmax.  These equations are similar to the
	default blending equation, but produce the difference of its left
	and right hand sides, rather than the sum.  Image differences are
	useful in many image processing applications.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/blend_subtract.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.blend_subtract import *
from OpenGL.raw.GL.EXT.blend_subtract import _EXTENSION_NAME

def glInitBlendSubtractEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_APPLE_clip_distance'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_APPLE_clip_distance',error_checker=_errors._error_checker)
GL_CLIP_DISTANCE0_APPLE=_C('GL_CLIP_DISTANCE0_APPLE',0x3000)
GL_CLIP_DISTANCE1_APPLE=_C('GL_CLIP_DISTANCE1_APPLE',0x3001)
GL_CLIP_DISTANCE2_APPLE=_C('GL_CLIP_DISTANCE2_APPLE',0x3002)
GL_CLIP_DISTANCE3_APPLE=_C('GL_CLIP_DISTANCE3_APPLE',0x3003)
GL_CLIP_DISTANCE4_APPLE=_C('GL_CLIP_DISTANCE4_APPLE',0x3004)
GL_CLIP_DISTANCE5_APPLE=_C('GL_CLIP_DISTANCE5_APPLE',0x3005)
GL_CLIP_DISTANCE6_APPLE=_C('GL_CLIP_DISTANCE6_APPLE',0x3006)
GL_CLIP_DISTANCE7_APPLE=_C('GL_CLIP_DISTANCE7_APPLE',0x3007)
GL_MAX_CLIP_DISTANCES_APPLE=_C('GL_MAX_CLIP_DISTANCES_APPLE',0x0D32)




'''OpenGL extension SGIS.generate_mipmap

This module customises the behaviour of the 
OpenGL.raw.GL.SGIS.generate_mipmap to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines a mechanism by which OpenGL can derive the
	entire set of mipmap arrays when provided with only the base level
	array.  Automatic mipmap generation is particularly useful when
	texture images are being provided as a video stream.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIS/generate_mipmap.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIS.generate_mipmap import *
from OpenGL.raw.GL.SGIS.generate_mipmap import _EXTENSION_NAME

def glInitGenerateMipmapSGIS():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


"""Integer values looked up via glGetIntegerv( constant )"""
import ctypes
_get = None

class LookupInt( object ):
    def __init__( self, lookup, format=ctypes.c_int ):
        self.lookup = lookup 
        self.format = format
    def __int__( self ):
        global _get
        if _get is None:
            from OpenGL.GL import glGetIntegerv
            _get = glGetIntegerv
        output = self.format()
        _get( self.lookup, output )
        return output.value
    def __eq__( self, other ):
        return int(self) == other
    def __cmp__( self, other ):
        return cmp( int(self), other )
    
